webbpsf\_ext.image\_manip
=========================

.. automodule:: webbpsf_ext.image_manip

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      convolve_image
      crop_zero_rows_cols
      distort_image
      fourier_imshift
      frebin
      fshift
      image_rescale
      make_disk_image
      model_to_hdulist
      pad_or_cut_to_size
      rotate_offset
      rotate_shift_image
   
   

   
   
   

   
   
   



